/****************************************************************************
** Form implementation generated from reading ui file 'netgodialogbase.ui'
**
** Created: Fri Sep 10 19:18:28 2004
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.0   edited Nov 24 13:47 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "netgodialogbase.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qwidgetstack.h>
#include <qwidget.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qlistbox.h>
#include <qlineedit.h>
#include <qcombobox.h>
#include <qtextbrowser.h>
#include <qradiobutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const unsigned char image0_data[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x02,
    0xc8, 0x49, 0x44, 0x41, 0x54, 0x78, 0x9c, 0xa5, 0x93, 0xc1, 0x8b, 0xdc,
    0x64, 0x1c, 0x40, 0xdf, 0x0e, 0x39, 0x24, 0x12, 0x25, 0xa1, 0x53, 0x98,
    0xc0, 0x28, 0x06, 0x14, 0x9a, 0xe0, 0x42, 0x67, 0xe9, 0x61, 0xa7, 0x94,
    0xa2, 0x83, 0x47, 0x85, 0x8a, 0x7a, 0x68, 0x87, 0x3d, 0x79, 0x14, 0x4f,
    0x7b, 0xf0, 0x50, 0x2c, 0xd4, 0x1e, 0x5b, 0xbc, 0xf5, 0x50, 0x29, 0x3d,
    0x48, 0x57, 0xf0, 0xa0, 0x07, 0x5d, 0xe6, 0x22, 0x1d, 0xa5, 0xd5, 0x19,
    0xc1, 0x6d, 0x72, 0x58, 0x26, 0x29, 0x5a, 0x9a, 0x45, 0x87, 0x49, 0x2c,
    0xc3, 0x26, 0xb0, 0x61, 0xf3, 0xa1, 0x1f, 0xfd, 0x79, 0x58, 0x41, 0xa4,
    0x47, 0xdf, 0x7f, 0xf0, 0x1e, 0xbc, 0x15, 0x11, 0xe1, 0xff, 0xb0, 0xf2,
    0xe2, 0xc6, 0x8c, 0xc1, 0x7a, 0x48, 0x55, 0x97, 0x80, 0xcb, 0x78, 0x9a,
    0x30, 0xf0, 0x3c, 0x3a, 0x76, 0x0c, 0xba, 0x47, 0xa5, 0x62, 0xc7, 0xb1,
    0x7b, 0x1f, 0x5b, 0x46, 0xfa, 0x46, 0x5e, 0xf8, 0x7d, 0xa5, 0xd3, 0x3f,
    0x94, 0x0e, 0x80, 0x88, 0xc9, 0x6e, 0x48, 0xcb, 0xea, 0x84, 0xa0, 0xa1,
    0xd7, 0x71, 0x01, 0x30, 0x09, 0x81, 0x94, 0xb5, 0x76, 0x0f, 0x55, 0xab,
    0xb3, 0x17, 0x4e, 0x0d, 0x46, 0xef, 0x6f, 0xb8, 0x1f, 0x5c, 0xfb, 0xe8,
    0xb4, 0x8f, 0xc1, 0x25, 0xdf, 0xf6, 0x19, 0xdd, 0x8b, 0x18, 0x7d, 0xb7,
    0x46, 0xb5, 0x4c, 0x68, 0x35, 0x45, 0x72, 0x4b, 0x69, 0xb6, 0xa6, 0xf3,
    0x72, 0x0b, 0xcd, 0x96, 0x52, 0xd1, 0xa7, 0xe8, 0xc0, 0x8e, 0x96, 0xe9,
    0x87, 0x9b, 0xe7, 0xbd, 0x6f, 0x4e, 0xbf, 0x49, 0x3f, 0x5c, 0x85, 0xb2,
    0x86, 0xcd, 0x33, 0xde, 0x46, 0xf4, 0x7b, 0x74, 0xd6, 0x34, 0x43, 0x30,
    0x22, 0x30, 0x42, 0xb8, 0x78, 0x43, 0x64, 0xb1, 0x2f, 0x32, 0x3b, 0x14,
    0xb9, 0xf9, 0x8b, 0xc8, 0xed, 0xbb, 0x22, 0x9b, 0x97, 0x65, 0x21, 0x8f,
    0xe5, 0x5f, 0x16, 0x22, 0xf2, 0xa7, 0x88, 0x3c, 0x12, 0xb9, 0x7a, 0xf9,
    0x70, 0x4a, 0x77, 0xfb, 0x05, 0xba, 0x0b, 0xe8, 0x6e, 0xd3, 0x4a, 0x97,
    0x79, 0xed, 0xb8, 0x90, 0x56, 0x10, 0x28, 0xa0, 0xc8, 0xb8, 0x76, 0x09,
    0x8f, 0xe3, 0x47, 0x91, 0xca, 0x12, 0xf0, 0x20, 0x2f, 0xa0, 0x31, 0x81,
    0x76, 0xb1, 0xde, 0xe9, 0x84, 0xe7, 0x50, 0x93, 0x63, 0x10, 0x1e, 0x6b,
    0x05, 0x6d, 0x8f, 0x14, 0xf0, 0x0a, 0x08, 0x6a, 0x18, 0xbe, 0xeb, 0xff,
    0xa7, 0xb2, 0xeb, 0x02, 0x0d, 0x8c, 0x7f, 0x82, 0x77, 0xae, 0x02, 0xa6,
    0x8f, 0xbf, 0xda, 0x5c, 0xb9, 0x70, 0xfe, 0xed, 0x2f, 0x4c, 0xdb, 0xfc,
    0xdc, 0x88, 0x8b, 0x9c, 0x8b, 0x78, 0xdc, 0xaa, 0x1a, 0xd2, 0x5d, 0x0b,
    0xb5, 0x6c, 0x08, 0x1c, 0x8b, 0xa8, 0x28, 0x09, 0xfe, 0x72, 0x89, 0x75,
    0x4e, 0xfa, 0xd0, 0x23, 0x5b, 0x66, 0xf8, 0x27, 0x7d, 0x46, 0x35, 0xb8,
    0xeb, 0xe1, 0x73, 0x93, 0x1f, 0xca, 0x57, 0x51, 0xdc, 0x6f, 0x05, 0x6d,
    0x0f, 0x0b, 0xc8, 0x73, 0x8b, 0x89, 0x86, 0xd7, 0x4e, 0x58, 0xe4, 0x06,
    0xac, 0x9d, 0x70, 0x89, 0x9f, 0x05, 0xcf, 0xf3, 0x70, 0xba, 0x30, 0x7c,
    0xcb, 0x27, 0x5b, 0x82, 0x67, 0x40, 0xf2, 0x3d, 0x4f, 0xf6, 0xbe, 0xa5,
    0xa5, 0xea, 0xe8, 0x8e, 0x11, 0x15, 0x19, 0x25, 0x3e, 0xe3, 0x9d, 0x8c,
    0xc9, 0x27, 0x3e, 0x49, 0x0e, 0xc3, 0x97, 0xe1, 0xcb, 0x0c, 0xe8, 0xc2,
    0xf8, 0xe7, 0x23, 0xff, 0xd1, 0x4e, 0x83, 0xca, 0x2d, 0xe2, 0x07, 0x11,
    0xaa, 0xf0, 0x17, 0x18, 0x93, 0x67, 0x30, 0xc3, 0x1d, 0x63, 0xad, 0xe3,
    0x73, 0xfd, 0x1e, 0x0c, 0x4f, 0xfd, 0xe3, 0x6e, 0xc2, 0xf5, 0x29, 0x98,
    0x1a, 0xa6, 0x53, 0xc8, 0x15, 0xe4, 0x31, 0x54, 0x7b, 0x47, 0x7a, 0x68,
    0x5f, 0x20, 0x7e, 0x82, 0x11, 0xfe, 0x86, 0x8e, 0x92, 0x56, 0xba, 0xcc,
    0x48, 0x63, 0x70, 0x9e, 0x6f, 0xc8, 0x81, 0xaf, 0xf6, 0x20, 0xc9, 0x60,
    0xfc, 0x2b, 0xa0, 0x41, 0xcd, 0x1b, 0xaa, 0x25, 0x28, 0x95, 0x81, 0x69,
    0x01, 0x19, 0x10, 0x38, 0xe8, 0x68, 0x06, 0xc1, 0x43, 0xc3, 0x51, 0x3e,
    0x4a, 0xc1, 0xe0, 0x15, 0x8b, 0xbc, 0x84, 0xe1, 0x4b, 0x30, 0xae, 0xa1,
    0x63, 0xc0, 0xd4, 0x80, 0xbe, 0x63, 0x31, 0x36, 0x00, 0xdb, 0x47, 0xed,
    0x25, 0x04, 0x07, 0xc1, 0xca, 0x68, 0x5e, 0xd9, 0x45, 0x11, 0xec, 0x42,
    0xaa, 0x31, 0xcf, 0xdc, 0x3f, 0xb8, 0x79, 0x43, 0x9e, 0x62, 0xff, 0xf1,
    0xa1, 0xc8, 0xa1, 0xc8, 0xa3, 0x64, 0x5f, 0x64, 0x21, 0xf2, 0xe3, 0xdd,
    0x85, 0x2c, 0x22, 0x91, 0xed, 0xaf, 0x67, 0xd2, 0x3f, 0xb7, 0x5f, 0x63,
    0xdf, 0x7e, 0x1d, 0x67, 0x46, 0x0b, 0x15, 0xd0, 0x59, 0x7d, 0xfa, 0x32,
    0xf7, 0xb8, 0x05, 0x35, 0xf8, 0x1d, 0x97, 0x64, 0x0e, 0x41, 0xdb, 0x83,
    0x39, 0x84, 0x4e, 0x48, 0xfa, 0x60, 0xb2, 0x80, 0xde, 0x14, 0x52, 0x56,
    0x38, 0x79, 0xa7, 0xec, 0xf7, 0x07, 0xb6, 0x69, 0x24, 0x40, 0x08, 0x3a,
    0x01, 0x1d, 0xa2, 0x54, 0x84, 0xd2, 0x01, 0xea, 0x60, 0x0a, 0x3a, 0xa0,
    0x51, 0x11, 0xe8, 0x90, 0xaa, 0x8e, 0xa8, 0xe6, 0xc1, 0x67, 0xa8, 0xf8,
    0x3d, 0x8c, 0x1e, 0x7f, 0x03, 0xa3, 0x61, 0x7f, 0x51, 0x28, 0x61, 0x9e,
    0xee, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60,
    0x82
};

static const unsigned char image1_data[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x02,
    0xcd, 0x49, 0x44, 0x41, 0x54, 0x78, 0x9c, 0xa5, 0x93, 0x41, 0x88, 0xdc,
    0x64, 0x00, 0x85, 0xbf, 0x1d, 0x02, 0x26, 0x12, 0x4b, 0x42, 0xb7, 0x30,
    0x81, 0x51, 0x9a, 0x5b, 0x67, 0x68, 0x61, 0x93, 0xd3, 0x26, 0x14, 0xd1,
    0xc5, 0x53, 0xf5, 0x50, 0x90, 0x9e, 0xca, 0x5c, 0x9c, 0x63, 0xf5, 0xa2,
    0x37, 0x2d, 0x85, 0x5a, 0xa4, 0x97, 0xea, 0xc9, 0x1e, 0x04, 0xf5, 0x20,
    0x55, 0x28, 0xba, 0x1e, 0x64, 0xc9, 0x45, 0x3a, 0x95, 0xae, 0x26, 0x97,
    0xed, 0x04, 0x5c, 0x36, 0x53, 0x64, 0xd9, 0x0c, 0x3a, 0x4c, 0xc6, 0x1a,
    0x26, 0x81, 0x1d, 0x9b, 0x9f, 0xfa, 0xd3, 0xdf, 0xc3, 0x0a, 0x22, 0x3d,
    0xfa, 0x5d, 0xde, 0xf5, 0x7d, 0x0f, 0xde, 0x8a, 0x52, 0x8a, 0xff, 0xc3,
    0xca, 0xc9, 0xfe, 0x1e, 0x1b, 0xeb, 0x3d, 0xea, 0x65, 0x05, 0xd8, 0x0c,
    0x93, 0x8c, 0x0d, 0xc7, 0xa5, 0x6d, 0x26, 0x20, 0x03, 0x6a, 0x91, 0x58,
    0x96, 0x19, 0xbc, 0x6f, 0x68, 0xe9, 0x6b, 0xc5, 0xbc, 0x1b, 0x08, 0x99,
    0xfe, 0x2e, 0xa4, 0x07, 0xc4, 0xc4, 0xbb, 0x3e, 0x2d, 0xa3, 0xd3, 0x03,
    0x09, 0x41, 0xc7, 0x06, 0x40, 0xa7, 0x07, 0xa4, 0x84, 0xed, 0x00, 0xb1,
    0x14, 0x2f, 0x0e, 0xd6, 0x37, 0xa2, 0x4b, 0x7d, 0xe3, 0xad, 0x1b, 0x57,
    0x43, 0x17, 0x8d, 0x2b, 0x5d, 0xab, 0x4b, 0xb4, 0x1d, 0x13, 0xdd, 0x0d,
    0xa9, 0xcb, 0x11, 0x5a, 0x33, 0xcd, 0x3e, 0x17, 0xab, 0xbd, 0x67, 0xee,
    0x4e, 0x2a, 0x74, 0x6c, 0x84, 0x18, 0xfd, 0x89, 0xf4, 0xde, 0x8e, 0xe7,
    0xe9, 0xa5, 0xcb, 0xfd, 0xf0, 0x5d, 0xeb, 0x14, 0xc7, 0xec, 0x13, 0x50,
    0xfd, 0x01, 0xef, 0x9d, 0xb5, 0xfb, 0x6f, 0x7e, 0xbd, 0x79, 0x5b, 0xd7,
    0xc3, 0x7b, 0x42, 0xc4, 0x80, 0x0f, 0xd7, 0x3e, 0x53, 0x6a, 0xb1, 0x50,
    0xea, 0xe0, 0xb1, 0x52, 0x9f, 0xfe, 0xa2, 0xd4, 0x37, 0xb1, 0x52, 0xef,
    0x5c, 0x55, 0x33, 0xb5, 0x50, 0xff, 0x32, 0xfb, 0x27, 0x0f, 0x94, 0xfa,
    0xf8, 0x03, 0x95, 0xd0, 0xd9, 0x7a, 0x81, 0xce, 0x02, 0x3a, 0x5b, 0xb4,
    0xd2, 0x79, 0xb1, 0xb4, 0x6d, 0x18, 0x95, 0xe0, 0x49, 0x10, 0xd3, 0x9c,
    0x1b, 0x57, 0x70, 0x38, 0x32, 0xa2, 0xaa, 0x00, 0x07, 0x8a, 0xdf, 0x00,
    0x13, 0x1a, 0x2b, 0x5f, 0x6f, 0xb7, 0xfd, 0xf3, 0x88, 0xe1, 0x71, 0xf0,
    0x8f, 0xb7, 0xbc, 0xb6, 0xc3, 0x08, 0x70, 0x4b, 0xe8, 0xd6, 0x70, 0xf1,
    0x82, 0xfb, 0x9f, 0x95, 0x6d, 0x1b, 0x68, 0x20, 0xde, 0x81, 0x57, 0xaf,
    0x83, 0x61, 0xba, 0xb8, 0x67, 0xaa, 0x6b, 0x6f, 0xf4, 0x5f, 0xbf, 0xad,
    0x9b, 0xfa, 0x57, 0x5a, 0x32, 0x2d, 0xb8, 0x8c, 0xc3, 0xcd, 0xb2, 0x61,
    0xbc, 0x6b, 0x50, 0x97, 0x0d, 0xde, 0xaa, 0x41, 0x3c, 0xad, 0xf0, 0xff,
    0xb2, 0x89, 0x65, 0xc1, 0x78, 0xdf, 0x21, 0x2f, 0x73, 0xdc, 0x35, 0x97,
    0xcd, 0x1a, 0xec, 0xf5, 0xde, 0xb1, 0xe1, 0x8f, 0xd5, 0x4b, 0x08, 0xee,
    0xb7, 0xbc, 0xb6, 0x73, 0x54, 0xb5, 0x34, 0x18, 0x4a, 0x38, 0x77, 0xda,
    0x20, 0x07, 0xc2, 0xd3, 0x36, 0xf1, 0x73, 0xe0, 0x3e, 0xef, 0x60, 0x75,
    0x60, 0x70, 0xc1, 0x25, 0x2f, 0xc1, 0xd5, 0x21, 0xfb, 0x81, 0x27, 0x93,
    0xef, 0xf5, 0x96, 0x58, 0xc6, 0x77, 0xb4, 0x78, 0x9a, 0xd3, 0xe0, 0x12,
    0x25, 0x39, 0xf1, 0x47, 0x2e, 0x59, 0x01, 0x17, 0x03, 0xd8, 0xcc, 0x81,
    0x93, 0x10, 0x25, 0x50, 0xcc, 0x21, 0xda, 0x69, 0x10, 0x85, 0x41, 0xfa,
    0x60, 0x84, 0x98, 0x77, 0x67, 0x68, 0xc3, 0x67, 0xd1, 0xfd, 0x1d, 0x2d,
    0xec, 0xb8, 0x7c, 0xb8, 0x0d, 0x83, 0xe0, 0xc8, 0xdd, 0x30, 0xe1, 0x66,
    0x02, 0x16, 0x90, 0x6c, 0x43, 0x21, 0xa1, 0x48, 0xa1, 0x9e, 0x18, 0x88,
    0x12, 0x90, 0x5d, 0x05, 0xc9, 0x13, 0x34, 0xff, 0x57, 0x64, 0x9c, 0xb5,
    0xd2, 0x79, 0xce, 0x38, 0x05, 0xbd, 0xdd, 0x50, 0x01, 0x5f, 0xee, 0x43,
    0x96, 0x43, 0x34, 0x06, 0x24, 0x88, 0x49, 0x43, 0x5d, 0x82, 0x10, 0x39,
    0xe8, 0x00, 0x63, 0xc0, 0xb3, 0x90, 0xf1, 0x1e, 0xf8, 0xfb, 0x5a, 0x5b,
    0xba, 0xd4, 0x02, 0xce, 0xad, 0x19, 0xe4, 0x15, 0x0c, 0x4e, 0x41, 0xb4,
    0x3c, 0x72, 0x1d, 0x6a, 0xf0, 0xf2, 0xaa, 0x41, 0xa4, 0x01, 0x96, 0x8b,
    0xd8, 0xcf, 0xf0, 0x0e, 0xfd, 0x95, 0x6f, 0xa7, 0x95, 0x39, 0x9f, 0xfb,
    0xbb, 0x30, 0x92, 0xe8, 0x67, 0xef, 0x1f, 0xde, 0xfa, 0x44, 0x3d, 0xc5,
    0xe2, 0xe1, 0x23, 0xa5, 0x1e, 0x2b, 0x75, 0x90, 0x2d, 0x94, 0x7a, 0xa8,
    0xd4, 0x4f, 0xf7, 0x66, 0x6a, 0xf1, 0xb3, 0x52, 0x5b, 0xdf, 0xed, 0xa9,
    0xe0, 0xfc, 0xa3, 0x25, 0xe6, 0xad, 0x57, 0xb0, 0x0e, 0x68, 0x21, 0x7c,
    0xac, 0x33, 0x4f, 0xbf, 0xcc, 0x3e, 0x61, 0x40, 0x0d, 0x6e, 0xc7, 0x26,
    0x9b, 0x80, 0xd7, 0x76, 0x60, 0x02, 0xfe, 0x6a, 0x8f, 0xf1, 0x83, 0xe1,
    0x0c, 0xc2, 0x04, 0x46, 0xac, 0xb0, 0x76, 0xa7, 0x0a, 0x82, 0x0d, 0x53,
    0xd7, 0x32, 0xa0, 0x07, 0x32, 0x03, 0xd9, 0x43, 0x88, 0x11, 0x42, 0xfa,
    0x88, 0xc3, 0x21, 0x48, 0x8f, 0x46, 0xc4, 0x20, 0x7d, 0xea, 0x65, 0x4c,
    0x3d, 0xf5, 0xbf, 0x40, 0xc4, 0x03, 0xb4, 0x90, 0xbf, 0x01, 0xe3, 0xf0,
    0x7d, 0xea, 0x4f, 0x5a, 0xad, 0xc3, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
    0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};


/*
 *  Constructs a netGoDialogBase as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
netGoDialogBase::netGoDialogBase( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    QImage img;
    img.loadFromData( image0_data, sizeof( image0_data ), "PNG" );
    image0 = img;
    img.loadFromData( image1_data, sizeof( image1_data ), "PNG" );
    image1 = img;
    if ( !name )
	setName( "netGoDialogBase" );
    setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    netGoDialogBaseLayout = new QGridLayout( this, 1, 1, 11, 6, "netGoDialogBaseLayout"); 
    netGoDialogBaseLayout->setResizeMode( QLayout::Fixed );

    widgetStack = new QWidgetStack( this, "widgetStack" );

    WStackPage = new QWidget( widgetStack, "WStackPage" );
    WStackPageLayout = new QGridLayout( WStackPage, 1, 1, 11, 6, "WStackPageLayout"); 

    mainGB = new QGroupBox( WStackPage, "mainGB" );
    mainGB->setColumnLayout(0, Qt::Vertical );
    mainGB->layout()->setSpacing( 6 );
    mainGB->layout()->setMargin( 11 );
    mainGBLayout = new QGridLayout( mainGB->layout() );
    mainGBLayout->setAlignment( Qt::AlignTop );
    spacer8 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding );
    mainGBLayout->addItem( spacer8, 2, 1 );
    spacer11_2 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding );
    mainGBLayout->addItem( spacer11_2, 4, 1 );

    textLabel1_3 = new QLabel( mainGB, "textLabel1_3" );

    mainGBLayout->addMultiCellWidget( textLabel1_3, 3, 3, 0, 2 );

    profileLB = new QListBox( mainGB, "profileLB" );

    mainGBLayout->addMultiCellWidget( profileLB, 1, 1, 0, 1 );

    layout17 = new QGridLayout( 0, 1, 1, 0, 6, "layout17"); 

    mainGoBut = new QPushButton( mainGB, "mainGoBut" );
    mainGoBut->setDefault( TRUE );

    layout17->addWidget( mainGoBut, 0, 1 );
    spacer59 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout17->addItem( spacer59, 0, 0 );

    addProfileBut = new QPushButton( mainGB, "addProfileBut" );
    addProfileBut->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 0, 0, addProfileBut->sizePolicy().hasHeightForWidth() ) );

    layout17->addMultiCellWidget( addProfileBut, 3, 3, 0, 1 );

    quitBut = new QPushButton( mainGB, "quitBut" );

    layout17->addWidget( quitBut, 1, 1 );
    spacer58 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout17->addItem( spacer58, 2, 1 );

    editProfileBut = new QPushButton( mainGB, "editProfileBut" );
    editProfileBut->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 0, 0, editProfileBut->sizePolicy().hasHeightForWidth() ) );

    layout17->addMultiCellWidget( editProfileBut, 4, 4, 0, 1 );

    delProfileBut = new QPushButton( mainGB, "delProfileBut" );
    delProfileBut->setPaletteForegroundColor( QColor( 0, 0, 0 ) );

    layout17->addMultiCellWidget( delProfileBut, 5, 5, 0, 1 );

    mainGBLayout->addMultiCellLayout( layout17, 1, 1, 2, 3 );
    spacer24 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
    mainGBLayout->addItem( spacer24, 0, 0 );

    versionLabel = new QLabel( mainGB, "versionLabel" );
    versionLabel->setMinimumSize( QSize( 0, 0 ) );
    versionLabel->setMaximumSize( QSize( 3000, 25 ) );

    mainGBLayout->addWidget( versionLabel, 5, 3 );

    WStackPageLayout->addWidget( mainGB, 0, 0 );
    widgetStack->addWidget( WStackPage, 0 );

    WStackPage_2 = new QWidget( widgetStack, "WStackPage_2" );
    WStackPageLayout_2 = new QGridLayout( WStackPage_2, 1, 1, 11, 6, "WStackPageLayout_2"); 

    addProfileGB = new QGroupBox( WStackPage_2, "addProfileGB" );
    addProfileGB->setEnabled( TRUE );
    addProfileGB->setColumnLayout(0, Qt::Vertical );
    addProfileGB->layout()->setSpacing( 6 );
    addProfileGB->layout()->setMargin( 11 );
    addProfileGBLayout = new QGridLayout( addProfileGB->layout() );
    addProfileGBLayout->setAlignment( Qt::AlignTop );

    layout30 = new QGridLayout( 0, 1, 1, 0, 6, "layout30"); 

    moreSettingsBut = new QPushButton( addProfileGB, "moreSettingsBut" );
    moreSettingsBut->setAutoDefault( FALSE );

    layout30->addMultiCellWidget( moreSettingsBut, 1, 1, 0, 1 );

    addProfileCancelBut = new QPushButton( addProfileGB, "addProfileCancelBut" );

    layout30->addMultiCellWidget( addProfileCancelBut, 3, 3, 1, 2 );
    spacer6_2 = new QSpacerItem( 63, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout30->addItem( spacer6_2, 3, 3 );
    spacer14_2 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout30->addItem( spacer14_2, 0, 0 );

    addProfileOkBut = new QPushButton( addProfileGB, "addProfileOkBut" );
    addProfileOkBut->setDefault( TRUE );

    layout30->addWidget( addProfileOkBut, 3, 0 );
    spacer18 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout30->addItem( spacer18, 2, 0 );
    spacer135 = new QSpacerItem( 70, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout30->addMultiCell( spacer135, 1, 1, 2, 3 );

    addProfileGBLayout->addLayout( layout30, 1, 0 );

    layout72 = new QGridLayout( 0, 1, 1, 0, 6, "layout72"); 

    gwLE = new QLineEdit( addProfileGB, "gwLE" );

    layout72->addMultiCellWidget( gwLE, 4, 4, 1, 2 );

    searchLabel = new QLabel( addProfileGB, "searchLabel" );

    layout72->addMultiCellWidget( searchLabel, 7, 7, 0, 1 );

    nameLabel = new QLabel( addProfileGB, "nameLabel" );
    nameLabel->setAlignment( int( QLabel::AlignVCenter ) );

    layout72->addWidget( nameLabel, 0, 0 );

    ipLE = new QLineEdit( addProfileGB, "ipLE" );

    layout72->addMultiCellWidget( ipLE, 2, 2, 1, 2 );

    ipLabel = new QLabel( addProfileGB, "ipLabel" );

    layout72->addWidget( ipLabel, 2, 0 );

    interfaceLabel = new QLabel( addProfileGB, "interfaceLabel" );

    layout72->addWidget( interfaceLabel, 1, 0 );

    nameserverLabel2 = new QLabel( addProfileGB, "nameserverLabel2" );

    layout72->addMultiCellWidget( nameserverLabel2, 6, 6, 0, 1 );

    ns1LE = new QLineEdit( addProfileGB, "ns1LE" );

    layout72->addWidget( ns1LE, 5, 2 );

    gwLabel = new QLabel( addProfileGB, "gwLabel" );

    layout72->addWidget( gwLabel, 4, 0 );

    netmaskLabel = new QLabel( addProfileGB, "netmaskLabel" );

    layout72->addWidget( netmaskLabel, 3, 0 );

    ns1Label = new QLabel( addProfileGB, "ns1Label" );

    layout72->addMultiCellWidget( ns1Label, 5, 5, 0, 1 );

    searchLE = new QLineEdit( addProfileGB, "searchLE" );

    layout72->addWidget( searchLE, 7, 2 );

    netmaskLE = new QLineEdit( addProfileGB, "netmaskLE" );

    layout72->addMultiCellWidget( netmaskLE, 3, 3, 1, 2 );

    ifaceCB = new QComboBox( FALSE, addProfileGB, "ifaceCB" );
    ifaceCB->setEditable( FALSE );

    layout72->addMultiCellWidget( ifaceCB, 1, 1, 1, 2 );

    ns2LE = new QLineEdit( addProfileGB, "ns2LE" );

    layout72->addWidget( ns2LE, 6, 2 );

    nameLE = new QLineEdit( addProfileGB, "nameLE" );

    layout72->addMultiCellWidget( nameLE, 0, 0, 1, 2 );

    addProfileGBLayout->addLayout( layout72, 0, 0 );

    WStackPageLayout_2->addWidget( addProfileGB, 0, 0 );
    widgetStack->addWidget( WStackPage_2, 1 );

    WStackPage_3 = new QWidget( widgetStack, "WStackPage_3" );
    WStackPageLayout_3 = new QGridLayout( WStackPage_3, 1, 1, 11, 6, "WStackPageLayout_3"); 

    runProfileGB = new QGroupBox( WStackPage_3, "runProfileGB" );
    runProfileGB->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    runProfileGB->setColumnLayout(0, Qt::Vertical );
    runProfileGB->layout()->setSpacing( 6 );
    runProfileGB->layout()->setMargin( 11 );
    runProfileGBLayout = new QGridLayout( runProfileGB->layout() );
    runProfileGBLayout->setAlignment( Qt::AlignTop );
    spacer9 = new QSpacerItem( 81, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    runProfileGBLayout->addItem( spacer9, 1, 2 );

    runProfileOkBut = new QPushButton( runProfileGB, "runProfileOkBut" );
    runProfileOkBut->setDefault( TRUE );

    runProfileGBLayout->addWidget( runProfileOkBut, 1, 0 );

    runProfileCancelBut = new QPushButton( runProfileGB, "runProfileCancelBut" );
    runProfileCancelBut->setAutoDefault( FALSE );

    runProfileGBLayout->addWidget( runProfileCancelBut, 1, 1 );

    procBrowser = new QTextBrowser( runProfileGB, "procBrowser" );
    procBrowser->setPaletteForegroundColor( QColor( 0, 85, 127 ) );
    procBrowser->setFrameShape( QTextBrowser::NoFrame );

    runProfileGBLayout->addMultiCellWidget( procBrowser, 0, 0, 0, 2 );

    WStackPageLayout_3->addWidget( runProfileGB, 0, 0 );
    widgetStack->addWidget( WStackPage_3, 2 );

    WStackPage_4 = new QWidget( widgetStack, "WStackPage_4" );
    WStackPageLayout_4 = new QGridLayout( WStackPage_4, 1, 1, 11, 6, "WStackPageLayout_4"); 

    addProfileGB_2 = new QGroupBox( WStackPage_4, "addProfileGB_2" );
    addProfileGB_2->setEnabled( TRUE );
    addProfileGB_2->setColumnLayout(0, Qt::Vertical );
    addProfileGB_2->layout()->setSpacing( 6 );
    addProfileGB_2->layout()->setMargin( 11 );
    addProfileGB_2Layout = new QGridLayout( addProfileGB_2->layout() );
    addProfileGB_2Layout->setAlignment( Qt::AlignTop );

    layout32 = new QGridLayout( 0, 1, 1, 0, 6, "layout32"); 

    editMoreSettingsBut = new QPushButton( addProfileGB_2, "editMoreSettingsBut" );
    editMoreSettingsBut->setMaximumSize( QSize( 32767, 32767 ) );
    editMoreSettingsBut->setAutoDefault( FALSE );

    layout32->addMultiCellWidget( editMoreSettingsBut, 1, 1, 0, 1 );
    spacer14_2_2 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout32->addItem( spacer14_2_2, 0, 0 );

    editProfileCancelBut = new QPushButton( addProfileGB_2, "editProfileCancelBut" );

    layout32->addMultiCellWidget( editProfileCancelBut, 3, 3, 1, 2 );
    spacer18_2 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout32->addItem( spacer18_2, 2, 0 );

    editProfileSaveBut = new QPushButton( addProfileGB_2, "editProfileSaveBut" );
    editProfileSaveBut->setDefault( TRUE );

    layout32->addWidget( editProfileSaveBut, 3, 0 );
    spacer6_2_2 = new QSpacerItem( 50, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout32->addItem( spacer6_2_2, 3, 3 );
    spacer134 = new QSpacerItem( 50, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout32->addMultiCell( spacer134, 1, 1, 2, 3 );

    addProfileGB_2Layout->addLayout( layout32, 1, 0 );

    layout73 = new QGridLayout( 0, 1, 1, 0, 6, "layout73"); 

    interfaceLabel_3 = new QLabel( addProfileGB_2, "interfaceLabel_3" );

    layout73->addWidget( interfaceLabel_3, 1, 0 );

    ipLabel_3 = new QLabel( addProfileGB_2, "ipLabel_3" );

    layout73->addWidget( ipLabel_3, 2, 0 );

    editIpLE = new QLineEdit( addProfileGB_2, "editIpLE" );

    layout73->addMultiCellWidget( editIpLE, 2, 2, 1, 2 );

    editNetmaskLE = new QLineEdit( addProfileGB_2, "editNetmaskLE" );

    layout73->addMultiCellWidget( editNetmaskLE, 3, 3, 1, 2 );

    editSearchLE = new QLineEdit( addProfileGB_2, "editSearchLE" );

    layout73->addWidget( editSearchLE, 7, 2 );

    editGwLE = new QLineEdit( addProfileGB_2, "editGwLE" );

    layout73->addMultiCellWidget( editGwLE, 4, 4, 1, 2 );

    editNameLE = new QLineEdit( addProfileGB_2, "editNameLE" );

    layout73->addMultiCellWidget( editNameLE, 0, 0, 1, 2 );

    nameLabel_3 = new QLabel( addProfileGB_2, "nameLabel_3" );
    nameLabel_3->setAlignment( int( QLabel::AlignVCenter ) );

    layout73->addWidget( nameLabel_3, 0, 0 );

    searchLabel_2 = new QLabel( addProfileGB_2, "searchLabel_2" );

    layout73->addMultiCellWidget( searchLabel_2, 7, 7, 0, 1 );

    netmaskLabel_2 = new QLabel( addProfileGB_2, "netmaskLabel_2" );

    layout73->addWidget( netmaskLabel_2, 3, 0 );

    nameserverLabel2_2 = new QLabel( addProfileGB_2, "nameserverLabel2_2" );

    layout73->addMultiCellWidget( nameserverLabel2_2, 6, 6, 0, 1 );

    gwLabel_2 = new QLabel( addProfileGB_2, "gwLabel_2" );

    layout73->addWidget( gwLabel_2, 4, 0 );

    editNs2LE = new QLineEdit( addProfileGB_2, "editNs2LE" );

    layout73->addWidget( editNs2LE, 6, 2 );

    ns1Label_2 = new QLabel( addProfileGB_2, "ns1Label_2" );

    layout73->addMultiCellWidget( ns1Label_2, 5, 5, 0, 1 );

    editIfaceCB = new QComboBox( FALSE, addProfileGB_2, "editIfaceCB" );

    layout73->addMultiCellWidget( editIfaceCB, 1, 1, 1, 2 );

    editNs1LE = new QLineEdit( addProfileGB_2, "editNs1LE" );

    layout73->addWidget( editNs1LE, 5, 2 );

    addProfileGB_2Layout->addLayout( layout73, 0, 0 );

    WStackPageLayout_4->addWidget( addProfileGB_2, 0, 0 );
    widgetStack->addWidget( WStackPage_4, 3 );

    WStackPage_5 = new QWidget( widgetStack, "WStackPage_5" );
    WStackPageLayout_5 = new QGridLayout( WStackPage_5, 1, 1, 11, 6, "WStackPageLayout_5"); 

    moreOptionsGB = new QGroupBox( WStackPage_5, "moreOptionsGB" );
    moreOptionsGB->setColumnLayout(0, Qt::Vertical );
    moreOptionsGB->layout()->setSpacing( 6 );
    moreOptionsGB->layout()->setMargin( 11 );
    moreOptionsGBLayout = new QGridLayout( moreOptionsGB->layout() );
    moreOptionsGBLayout->setAlignment( Qt::AlignTop );
    spacer6_2_3 = new QSpacerItem( 189, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    moreOptionsGBLayout->addItem( spacer6_2_3, 4, 1 );

    moreSettingsBackBut = new QPushButton( moreOptionsGB, "moreSettingsBackBut" );
    moreSettingsBackBut->setDefault( TRUE );

    moreOptionsGBLayout->addWidget( moreSettingsBackBut, 4, 0 );

    layout21 = new QGridLayout( 0, 1, 1, 0, 6, "layout21"); 

    openBut = new QPushButton( moreOptionsGB, "openBut" );
    openBut->setPixmap( image0 );

    layout21->addWidget( openBut, 1, 1 );

    scriptLE = new QLineEdit( moreOptionsGB, "scriptLE" );

    layout21->addWidget( scriptLE, 1, 0 );

    textLabel1 = new QLabel( moreOptionsGB, "textLabel1" );

    layout21->addMultiCellWidget( textLabel1, 0, 0, 0, 1 );

    moreOptionsGBLayout->addMultiCellLayout( layout21, 0, 0, 0, 1 );
    spacer15 = new QSpacerItem( 20, 50, QSizePolicy::Minimum, QSizePolicy::Expanding );
    moreOptionsGBLayout->addItem( spacer15, 3, 0 );

    layout38 = new QGridLayout( 0, 1, 1, 0, 6, "layout38"); 

    keyLE = new QLineEdit( moreOptionsGB, "keyLE" );
    keyLE->setReadOnly( FALSE );

    layout38->addMultiCellWidget( keyLE, 3, 3, 1, 3 );

    nameLabel_2_2 = new QLabel( moreOptionsGB, "nameLabel_2_2" );
    nameLabel_2_2->setMinimumSize( QSize( 85, 0 ) );

    layout38->addWidget( nameLabel_2_2, 1, 0 );

    nameLabel_2 = new QLabel( moreOptionsGB, "nameLabel_2" );
    nameLabel_2->setMinimumSize( QSize( 85, 0 ) );

    layout38->addWidget( nameLabel_2, 2, 0 );

    textLabel2 = new QLabel( moreOptionsGB, "textLabel2" );

    layout38->addMultiCellWidget( textLabel2, 0, 0, 0, 1 );

    keyLabel = new QLabel( moreOptionsGB, "keyLabel" );
    keyLabel->setMinimumSize( QSize( 85, 0 ) );

    layout38->addWidget( keyLabel, 3, 0 );

    hexBox = new QRadioButton( moreOptionsGB, "hexBox" );

    layout38->addWidget( hexBox, 4, 3 );

    offBox = new QRadioButton( moreOptionsGB, "offBox" );
    offBox->setChecked( TRUE );

    layout38->addWidget( offBox, 4, 1 );

    modeCB = new QComboBox( FALSE, moreOptionsGB, "modeCB" );

    layout38->addMultiCellWidget( modeCB, 1, 1, 1, 3 );

    essidLE = new QLineEdit( moreOptionsGB, "essidLE" );

    layout38->addMultiCellWidget( essidLE, 2, 2, 1, 3 );

    asciiBox = new QRadioButton( moreOptionsGB, "asciiBox" );

    layout38->addWidget( asciiBox, 4, 2 );

    moreOptionsGBLayout->addMultiCellLayout( layout38, 2, 2, 0, 1 );
    spacer76 = new QSpacerItem( 20, 5, QSizePolicy::Minimum, QSizePolicy::Minimum );
    moreOptionsGBLayout->addItem( spacer76, 1, 0 );

    WStackPageLayout_5->addWidget( moreOptionsGB, 0, 0 );
    widgetStack->addWidget( WStackPage_5, 4 );

    WStackPage_6 = new QWidget( widgetStack, "WStackPage_6" );
    WStackPageLayout_6 = new QGridLayout( WStackPage_6, 1, 1, 11, 6, "WStackPageLayout_6"); 

    editWirelessGB = new QGroupBox( WStackPage_6, "editWirelessGB" );
    editWirelessGB->setColumnLayout(0, Qt::Vertical );
    editWirelessGB->layout()->setSpacing( 6 );
    editWirelessGB->layout()->setMargin( 11 );
    editWirelessGBLayout = new QGridLayout( editWirelessGB->layout() );
    editWirelessGBLayout->setAlignment( Qt::AlignTop );
    spacer6_2_3_2 = new QSpacerItem( 189, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    editWirelessGBLayout->addItem( spacer6_2_3_2, 4, 1 );

    editMoreBackBut = new QPushButton( editWirelessGB, "editMoreBackBut" );
    editMoreBackBut->setDefault( TRUE );

    editWirelessGBLayout->addWidget( editMoreBackBut, 4, 0 );

    layout21_2 = new QGridLayout( 0, 1, 1, 0, 6, "layout21_2"); 

    editOpenBut = new QPushButton( editWirelessGB, "editOpenBut" );
    editOpenBut->setPixmap( image1 );

    layout21_2->addWidget( editOpenBut, 1, 1 );

    editScriptLE = new QLineEdit( editWirelessGB, "editScriptLE" );

    layout21_2->addWidget( editScriptLE, 1, 0 );

    textLabel1_2 = new QLabel( editWirelessGB, "textLabel1_2" );

    layout21_2->addMultiCellWidget( textLabel1_2, 0, 0, 0, 1 );

    editWirelessGBLayout->addMultiCellLayout( layout21_2, 0, 0, 0, 1 );
    spacer15_2 = new QSpacerItem( 20, 60, QSizePolicy::Minimum, QSizePolicy::Expanding );
    editWirelessGBLayout->addItem( spacer15_2, 3, 0 );

    layout48 = new QGridLayout( 0, 1, 1, 0, 6, "layout48"); 

    nameLabel_2_2_2 = new QLabel( editWirelessGB, "nameLabel_2_2_2" );
    nameLabel_2_2_2->setMinimumSize( QSize( 85, 0 ) );

    layout48->addWidget( nameLabel_2_2_2, 1, 0 );

    nameLabel_2_4 = new QLabel( editWirelessGB, "nameLabel_2_4" );
    nameLabel_2_4->setMinimumSize( QSize( 85, 0 ) );

    layout48->addWidget( nameLabel_2_4, 2, 0 );

    editKeyLabel = new QLabel( editWirelessGB, "editKeyLabel" );
    editKeyLabel->setMinimumSize( QSize( 85, 0 ) );

    layout48->addWidget( editKeyLabel, 3, 0 );

    textLabel2_2 = new QLabel( editWirelessGB, "textLabel2_2" );

    layout48->addMultiCellWidget( textLabel2_2, 0, 0, 0, 1 );

    editHexBox = new QRadioButton( editWirelessGB, "editHexBox" );

    layout48->addWidget( editHexBox, 4, 3 );

    editEssidLE = new QLineEdit( editWirelessGB, "editEssidLE" );

    layout48->addMultiCellWidget( editEssidLE, 2, 2, 1, 3 );

    editAsciiBox = new QRadioButton( editWirelessGB, "editAsciiBox" );

    layout48->addWidget( editAsciiBox, 4, 2 );

    editOffBox = new QRadioButton( editWirelessGB, "editOffBox" );

    layout48->addWidget( editOffBox, 4, 1 );

    editKeyLE = new QLineEdit( editWirelessGB, "editKeyLE" );

    layout48->addMultiCellWidget( editKeyLE, 3, 3, 1, 3 );

    editModeCB = new QComboBox( FALSE, editWirelessGB, "editModeCB" );

    layout48->addMultiCellWidget( editModeCB, 1, 1, 1, 3 );

    editWirelessGBLayout->addMultiCellLayout( layout48, 2, 2, 0, 1 );
    spacer76_2 = new QSpacerItem( 20, 5, QSizePolicy::Minimum, QSizePolicy::Minimum );
    editWirelessGBLayout->addItem( spacer76_2, 1, 0 );

    WStackPageLayout_6->addWidget( editWirelessGB, 0, 0 );
    widgetStack->addWidget( WStackPage_6, 5 );

    netGoDialogBaseLayout->addWidget( widgetStack, 0, 0 );
    languageChange();
    resize( QSize(324, 372).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // tab order
    setTabOrder( mainGoBut, quitBut );
    setTabOrder( quitBut, addProfileBut );
    setTabOrder( addProfileBut, editProfileBut );
    setTabOrder( editProfileBut, delProfileBut );
    setTabOrder( delProfileBut, profileLB );
    setTabOrder( profileLB, nameLE );
    setTabOrder( nameLE, ifaceCB );
    setTabOrder( ifaceCB, ipLE );
    setTabOrder( ipLE, netmaskLE );
    setTabOrder( netmaskLE, gwLE );
    setTabOrder( gwLE, ns1LE );
    setTabOrder( ns1LE, ns2LE );
    setTabOrder( ns2LE, searchLE );
    setTabOrder( searchLE, moreSettingsBut );
    setTabOrder( moreSettingsBut, addProfileOkBut );
    setTabOrder( addProfileOkBut, addProfileCancelBut );
    setTabOrder( addProfileCancelBut, procBrowser );
    setTabOrder( procBrowser, runProfileOkBut );
    setTabOrder( runProfileOkBut, runProfileCancelBut );
    setTabOrder( runProfileCancelBut, editNameLE );
    setTabOrder( editNameLE, editIfaceCB );
    setTabOrder( editIfaceCB, editIpLE );
    setTabOrder( editIpLE, editNetmaskLE );
    setTabOrder( editNetmaskLE, editGwLE );
    setTabOrder( editGwLE, editNs1LE );
    setTabOrder( editNs1LE, editNs2LE );
    setTabOrder( editNs2LE, editSearchLE );
    setTabOrder( editSearchLE, editMoreSettingsBut );
    setTabOrder( editMoreSettingsBut, editProfileSaveBut );
    setTabOrder( editProfileSaveBut, editProfileCancelBut );
    setTabOrder( editProfileCancelBut, modeCB );
    setTabOrder( modeCB, essidLE );
    setTabOrder( essidLE, keyLE );
    setTabOrder( keyLE, moreSettingsBackBut );
    setTabOrder( moreSettingsBackBut, editMoreBackBut );
    init();
}

/*
 *  Destroys the object and frees any allocated resources
 */
netGoDialogBase::~netGoDialogBase()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void netGoDialogBase::languageChange()
{
    setCaption( tr( "netGo" ) );
    mainGB->setTitle( tr( "Choose profile" ) );
    textLabel1_3->setText( tr( "Select a profile in the list and \n"
"press \"Go!\" to execute it." ) );
    mainGoBut->setText( tr( "Go!" ) );
    addProfileBut->setText( tr( "Add profile" ) );
    quitBut->setText( tr( "Quit" ) );
    editProfileBut->setText( tr( "Edit profile" ) );
    delProfileBut->setText( tr( "Delete profile" ) );
    versionLabel->setText( tr( "dev" ) );
    addProfileGB->setTitle( tr( "Add profile" ) );
    moreSettingsBut->setText( tr( "More options" ) );
    addProfileCancelBut->setText( tr( "Cancel" ) );
    addProfileOkBut->setText( tr( "OK" ) );
    searchLabel->setText( tr( "Search domain:" ) );
    nameLabel->setText( tr( "Profile name:" ) );
    ipLabel->setText( tr( "Ip address:" ) );
    interfaceLabel->setText( tr( "Interface:" ) );
    nameserverLabel2->setText( tr( "Nameserver #2:" ) );
    gwLabel->setText( tr( "Gateway Ip:" ) );
    netmaskLabel->setText( tr( "Netmask:" ) );
    ns1Label->setText( tr( "Nameserver #1:" ) );
    ifaceCB->clear();
    ifaceCB->insertItem( tr( "None" ) );
    runProfileGB->setTitle( tr( "Executing profile" ) );
    runProfileOkBut->setText( tr( "OK" ) );
    runProfileCancelBut->setText( tr( "Cancel" ) );
    procBrowser->setText( QString::null );
    addProfileGB_2->setTitle( tr( "Edit profile" ) );
    editMoreSettingsBut->setText( tr( "More options" ) );
    editProfileCancelBut->setText( tr( "Cancel" ) );
    editProfileSaveBut->setText( tr( "Save" ) );
    interfaceLabel_3->setText( tr( "Interface:" ) );
    ipLabel_3->setText( tr( "Ip address:" ) );
    nameLabel_3->setText( tr( "Profile name:" ) );
    searchLabel_2->setText( tr( "Search domain:" ) );
    netmaskLabel_2->setText( tr( "Netmask:" ) );
    nameserverLabel2_2->setText( tr( "Nameserver #2:" ) );
    gwLabel_2->setText( tr( "Gateway Ip:" ) );
    ns1Label_2->setText( tr( "Nameserver #1:" ) );
    editIfaceCB->clear();
    editIfaceCB->insertItem( tr( "None" ) );
    moreOptionsGB->setTitle( tr( "More options" ) );
    moreSettingsBackBut->setText( tr( "Back" ) );
    openBut->setText( QString::null );
    textLabel1->setText( tr( "Custom script:" ) );
    nameLabel_2_2->setText( tr( "Mode:" ) );
    nameLabel_2->setText( tr( "Essid:" ) );
    textLabel2->setText( tr( "<b>Wireless options</b>" ) );
    keyLabel->setText( tr( "Key:" ) );
    hexBox->setText( tr( "hex" ) );
    offBox->setText( tr( "off" ) );
    modeCB->clear();
    modeCB->insertItem( tr( "None" ) );
    modeCB->insertItem( tr( "Managed" ) );
    modeCB->insertItem( tr( "Ad-Hoc" ) );
    asciiBox->setText( tr( "ascii" ) );
    editWirelessGB->setTitle( tr( "Edit more options" ) );
    editMoreBackBut->setText( tr( "Back" ) );
    editOpenBut->setText( QString::null );
    textLabel1_2->setText( tr( "Custom script:" ) );
    nameLabel_2_2_2->setText( tr( "Mode:" ) );
    nameLabel_2_4->setText( tr( "Essid:" ) );
    editKeyLabel->setText( tr( "Key:" ) );
    textLabel2_2->setText( tr( "<b>Wireless options</b>" ) );
    editHexBox->setText( tr( "hex" ) );
    editAsciiBox->setText( tr( "ascii" ) );
    editOffBox->setText( tr( "off" ) );
    editModeCB->clear();
    editModeCB->insertItem( tr( "None" ) );
    editModeCB->insertItem( tr( "Managed" ) );
    editModeCB->insertItem( tr( "Ad-Hoc" ) );
}

void netGoDialogBase::init()
{
}

