/****************************************************************************
** Form interface generated from reading ui file 'setupbase.ui'
**
** Created: Fri Sep 10 19:18:31 2004
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.0   edited Nov 24 13:47 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SETUPBASE_H
#define SETUPBASE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qwizard.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QWidget;
class QLabel;
class QLineEdit;
class QFrame;
class QRadioButton;

class SetupBase : public QWizard
{
    Q_OBJECT

public:
    SetupBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SetupBase();

    QWidget* pathPage;
    QLabel* pixmapLabel3;
    QLabel* textLabel2;
    QLineEdit* ifconfigPath;
    QLabel* textLabel2_2;
    QLineEdit* routePath;
    QLabel* textLabel2_5;
    QLineEdit* iwconfigPath;
    QLabel* textLabel1;
    QFrame* line3;
    QLineEdit* dhclientPath;
    QRadioButton* dhcpcdBox;
    QLabel* textLabel3;
    QRadioButton* dhclientBox;
    QLineEdit* dhcpcdPath;

protected:
    QGridLayout* pathPageLayout;
    QSpacerItem* spacer5;
    QSpacerItem* spacer7;
    QSpacerItem* spacer5_2;
    QVBoxLayout* layout4;
    QGridLayout* layout4_2;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;

};

#endif // SETUPBASE_H
