/* Copyright (C) 2004 Per Johansson
	
	This file is part of netGo.

    netGo is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    netGo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with netGo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <qobject.h>
#include <qregexp.h>

#include "setupbase.h"

// Subclassing SetupBase.
class Setup : public SetupBase
{
	Q_OBJECT
	
	public:
		Setup();
		
	public slots:
		void onDhcpcdCheck();
		void onDhclientCheck();
		
		void accept();
		void saveSettings(QString dhcpPath);
	private:
		QRegExp path;
};
