/****************************************************************************
** Form interface generated from reading ui file 'netgodialogbase.ui'
**
** Created: Fri Sep 10 19:18:28 2004
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.0   edited Nov 24 13:47 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef NETGODIALOGBASE_H
#define NETGODIALOGBASE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QWidgetStack;
class QWidget;
class QGroupBox;
class QLabel;
class QListBox;
class QListBoxItem;
class QPushButton;
class QLineEdit;
class QComboBox;
class QTextBrowser;
class QRadioButton;

class netGoDialogBase : public QDialog
{
    Q_OBJECT

public:
    netGoDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~netGoDialogBase();

    QWidgetStack* widgetStack;
    QWidget* WStackPage;
    QGroupBox* mainGB;
    QLabel* textLabel1_3;
    QListBox* profileLB;
    QPushButton* mainGoBut;
    QPushButton* addProfileBut;
    QPushButton* quitBut;
    QPushButton* editProfileBut;
    QPushButton* delProfileBut;
    QLabel* versionLabel;
    QWidget* WStackPage_2;
    QGroupBox* addProfileGB;
    QPushButton* moreSettingsBut;
    QPushButton* addProfileCancelBut;
    QPushButton* addProfileOkBut;
    QLineEdit* gwLE;
    QLabel* searchLabel;
    QLabel* nameLabel;
    QLineEdit* ipLE;
    QLabel* ipLabel;
    QLabel* interfaceLabel;
    QLabel* nameserverLabel2;
    QLineEdit* ns1LE;
    QLabel* gwLabel;
    QLabel* netmaskLabel;
    QLabel* ns1Label;
    QLineEdit* searchLE;
    QLineEdit* netmaskLE;
    QComboBox* ifaceCB;
    QLineEdit* ns2LE;
    QLineEdit* nameLE;
    QWidget* WStackPage_3;
    QGroupBox* runProfileGB;
    QPushButton* runProfileOkBut;
    QPushButton* runProfileCancelBut;
    QTextBrowser* procBrowser;
    QWidget* WStackPage_4;
    QGroupBox* addProfileGB_2;
    QPushButton* editMoreSettingsBut;
    QPushButton* editProfileCancelBut;
    QPushButton* editProfileSaveBut;
    QLabel* interfaceLabel_3;
    QLabel* ipLabel_3;
    QLineEdit* editIpLE;
    QLineEdit* editNetmaskLE;
    QLineEdit* editSearchLE;
    QLineEdit* editGwLE;
    QLineEdit* editNameLE;
    QLabel* nameLabel_3;
    QLabel* searchLabel_2;
    QLabel* netmaskLabel_2;
    QLabel* nameserverLabel2_2;
    QLabel* gwLabel_2;
    QLineEdit* editNs2LE;
    QLabel* ns1Label_2;
    QComboBox* editIfaceCB;
    QLineEdit* editNs1LE;
    QWidget* WStackPage_5;
    QGroupBox* moreOptionsGB;
    QPushButton* moreSettingsBackBut;
    QPushButton* openBut;
    QLineEdit* scriptLE;
    QLabel* textLabel1;
    QLineEdit* keyLE;
    QLabel* nameLabel_2_2;
    QLabel* nameLabel_2;
    QLabel* textLabel2;
    QLabel* keyLabel;
    QRadioButton* hexBox;
    QRadioButton* offBox;
    QComboBox* modeCB;
    QLineEdit* essidLE;
    QRadioButton* asciiBox;
    QWidget* WStackPage_6;
    QGroupBox* editWirelessGB;
    QPushButton* editMoreBackBut;
    QPushButton* editOpenBut;
    QLineEdit* editScriptLE;
    QLabel* textLabel1_2;
    QLabel* nameLabel_2_2_2;
    QLabel* nameLabel_2_4;
    QLabel* editKeyLabel;
    QLabel* textLabel2_2;
    QRadioButton* editHexBox;
    QLineEdit* editEssidLE;
    QRadioButton* editAsciiBox;
    QRadioButton* editOffBox;
    QLineEdit* editKeyLE;
    QComboBox* editModeCB;

protected:
    QGridLayout* netGoDialogBaseLayout;
    QGridLayout* WStackPageLayout;
    QGridLayout* mainGBLayout;
    QSpacerItem* spacer8;
    QSpacerItem* spacer11_2;
    QSpacerItem* spacer24;
    QGridLayout* layout17;
    QSpacerItem* spacer59;
    QSpacerItem* spacer58;
    QGridLayout* WStackPageLayout_2;
    QGridLayout* addProfileGBLayout;
    QGridLayout* layout30;
    QSpacerItem* spacer6_2;
    QSpacerItem* spacer14_2;
    QSpacerItem* spacer18;
    QSpacerItem* spacer135;
    QGridLayout* layout72;
    QGridLayout* WStackPageLayout_3;
    QGridLayout* runProfileGBLayout;
    QSpacerItem* spacer9;
    QGridLayout* WStackPageLayout_4;
    QGridLayout* addProfileGB_2Layout;
    QGridLayout* layout32;
    QSpacerItem* spacer14_2_2;
    QSpacerItem* spacer18_2;
    QSpacerItem* spacer6_2_2;
    QSpacerItem* spacer134;
    QGridLayout* layout73;
    QGridLayout* WStackPageLayout_5;
    QGridLayout* moreOptionsGBLayout;
    QSpacerItem* spacer6_2_3;
    QSpacerItem* spacer15;
    QSpacerItem* spacer76;
    QGridLayout* layout21;
    QGridLayout* layout38;
    QGridLayout* WStackPageLayout_6;
    QGridLayout* editWirelessGBLayout;
    QSpacerItem* spacer6_2_3_2;
    QSpacerItem* spacer15_2;
    QSpacerItem* spacer76_2;
    QGridLayout* layout21_2;
    QGridLayout* layout48;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;

    void init();

};

#endif // NETGODIALOGBASE_H
