/****************************************************************************
** Form interface generated from reading ui file 'msgbox.ui'
**
** Created: Fri Sep 10 19:18:32 2004
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.0   edited Nov 24 13:47 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef MSGBOX_H
#define MSGBOX_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QCheckBox;
class QPushButton;

class MsgBox : public QDialog
{
    Q_OBJECT

public:
    MsgBox( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~MsgBox();

    QLabel* text;
    QLabel* icon;
    QCheckBox* checkBox;
    QPushButton* okBut;

protected:
    QGridLayout* MsgBoxLayout;
    QSpacerItem* spacer3;
    QGridLayout* layout13;
    QGridLayout* layout11;
    QSpacerItem* spacer1;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;

};

#endif // MSGBOX_H
