/* Copyright (C) 2004 Per Johansson
	
	This file is part of netGo.

    netGo is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    netGo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with netGo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <qstring.h>

#ifndef SETTINGS_H
#define SETTINGS_H

// Class that stores the user settings.
class Settings
{
	public:
		Settings();
		
		static bool fetchSettings();
		static void dumpSettings();
		
		static QString IFCONFIG_PATH;
		static QString ROUTE_PATH;
		static QString IWCONFIG_PATH;
		static QString DHCP_CLIENT_PATH;
		static QString DHCP_CLIENT;

		static QString NOTIFY_TRAY;
};

#endif
